@@ -11,7 +11,10 @@ class Context:
         self, text: str, base64_attachments: list = None, listen: bool = False
     ):
         await self.bot.send(
-            self.message, text, base64_attachments=base64_attachments, listen=listen
+            self.message.group,
+            text,
+            base64_attachments=base64_attachments,
+            listen=listen,
         )
 
     async def react(self, emoji: str):
